<?php
$lang['addedit_billingform_template'] = 'Dodaj/uredi predlogo obrazca za zaračunavanje';
$lang['addedit_completion_template'] = 'Dodaj/uredi predlogo zaključka nakupa';
$lang['addedit_confirmorder_template'] = 'Dodaj/uredi predlogo za potrditev naročila';
$lang['addedit_gateway_complete_template'] = 'Dodaj/uredi predlogo za opravljeno plačilo';
$lang['addedit_invoice_template'] = 'Dodaj/uredi predlogo računa';
$lang['addedit_paymentform_template'] = 'Dodaj/uredi predlogo obrazca za plačilo';
$lang['address1'] = 'Naslov 1';
$lang['address2'] = 'Naslov 2';
$lang['add_msg_template'] = 'Dodaj predlogo sporočila';
$lang['admin_email_addresses'] = 'Seznam E-mail naslovov administratorjev, ki bodo obve&scaron;čeni o novem naročili';
$lang['admin_email_template'] = 'Predloga E-maila za administratorja';
$lang['any'] = 'Vse';
$lang['ask_delete'] = 'Ste prepričani, da želite izbrisati ta zapis?';
$lang['ask_delete_order'] = 'Ste prepričani, da želite izbrisati to naročilo? Brisanje naročil ni priporočljivo.';
$lang['ask_edit_billing'] = 'Ste prepričani, da želite spremeniti informacije za nakup pri tem naročilu, kot je navedeno zgoraj?';
$lang['ask_saveprefs'] = 'Ste prepričani, da želite spremeniti nastavitve tega modula?\nBodite pazljivi, napačne nastavitve lahko povzročijo napačno delovanje spletnih strani.';
$lang['back'] = 'Nazaj';
$lang['back_to_orders'] = 'Nazaj v naročila';
$lang['backorder'] = 'Nazaj naročeno';
$lang['bill_to'] = 'Podatki o kupcu';
$lang['billing_address'] = 'Naslov za račun';
$lang['billing_form_templates'] = 'Predloge obrazca za naročilo';
$lang['billing_info'] = 'Informacije za račun';
$lang['body'] = 'Vsebina sporočila';
$lang['cancel'] = 'Prekliči';
$lang['cancelled'] = 'Preklicano';
$lang['captcha_title'] = 'Captcha besedilo';
$lang['cart_module'] = 'Modul za voziček';
$lang['cart_settings'] = 'Nastavitve vozička';
$lang['cc_AMEX'] = 'American Express';
$lang['cc_Discover'] = 'Discover';
$lang['cc_MasterCard'] = 'Mastercard';
$lang['cc_Visa'] = 'Visa';
$lang['city'] = 'Kraj';
$lang['completed'] = 'Zaključeno';
$lang['completion_templates'] = 'Predloge za zaključek';
$lang['confirmed'] = 'Potrjeno';
$lang['confirm_order'] = 'Potrdite va&scaron;e naročilo';
$lang['confirmation_form_templates'] = 'Predloge za potrditev naročila';
$lang['confirmation_num'] = '&Scaron;tevilka potrdila';
$lang['country'] = 'Država';
$lang['created'] = 'Ustvarjeno';
$lang['create_invoice'] = 'Ustvari predlogo za to naročilo';
$lang['create_invoice_for'] = 'Ustvari predlogo za naročilo %s';
$lang['creditcard_expiry'] = 'Datum veljavnosti kreditne kartice';
$lang['creditcard_number'] = '&Scaron;tevilka kreditne kartice';
$lang['creditcard_type'] = 'Tip kreditne kartice';
$lang['creditcard_verifycode'] = 'Verifikacijska koda';
$lang['customer_name'] = 'Ime stranke';
$lang['dflt_billingform_template'] = 'Privzeta predloga za naročilo';
$lang['dflt_confirmorder_template'] = 'Privzeta predloga za potrditev naročila';
$lang['dflt_completion_template'] = 'Privzeta predloga za zaključek naročila';
$lang['dflt_gateway_complete_template'] = 'Privzeta predloga za opravljeno plačilo';
$lang['dflt_invoice_message'] = 'Zahvaljujemo se za va&scaron; nakup na straneh {sitename}.';
$lang['dflt_invoice_template'] = 'Privzeta predloga računa';
$lang['dflt_paymentform_template'] = 'Privzeta predloga obrazca za plačilo';
$lang['default_templates'] = 'Privzete predloge';
$lang['delete'] = 'Izbri&scaron;i';
$lang['description'] = 'Opis';
$lang['destinations'] = 'Destinacije';
$lang['details'] = 'Podrobnosti';
$lang['edit'] = 'Uredi';
$lang['edit_billing_info'] = 'Uredi informacije o kupcu';
$lang['email'] = 'Email';
$lang['email_address'] = 'Email naslov';
$lang['email_invoice'] = 'Po&scaron;lji ta račun kupcu in avtoriziranim administratorjem';
$lang['email_sent_to'] = 'Email poslan na';
$lang['email_subject'] = 'Email zadeva';
$lang['error_badcaptcha'] = 'Besedilo s slike ste prepisali napačno';
$lang['error_credicard_expired'] = 'Kreditna kartica ni veljavna';
$lang['error_encryption_problem'] = 'Pri&scaron;lo je do težav pri kriptiranju / dekriptiranju podatkov';
$lang['error_insufficientparams'] = 'Manjkajoč obvezen parameter';
$lang['error_invalidfield'] = 'Naslednje polje ni pravilno: %s';
$lang['error_missingshippinginfo'] = 'Niste podali dovolj informacij za dostavo';
$lang['error_namexists'] = 'Izdelek s tem imenom že obstaja';
$lang['error_nocartmodule'] = 'Ne morem najti modula za voziček. Prosimo preverite, ali je modul za voziček name&scaron;čen in izbran v nastavitvah modula Upravitelj Produktov.';
$lang['error_noemailaddress'] = 'Ta uporabnik nima dodeljenega nobenega Email naslova';
$lang['error_nofeumodule'] = 'Ne najdem modula FrontEndUsers';
$lang['error_nopaymentgateway'] = 'Noben sistem za plačilne kartice ni dodeljen';
$lang['error_noproductsmodule'] = 'Ne najdem modula Upravitelj Produktov';
$lang['error_notloggedin'] = 'Uporabnik ni prijavljen';
$lang['error_orderinvalid'] = 'Pri&scaron;lo je do napake pri tem naročilu (informacije niso konsistentne)';
$lang['error_ordernotfound'] = 'Ne najdem zahtevanega naročila';
$lang['error_orderprocessing'] = 'Pri&scaron;lo je do napake pri procesiranju naročila (napaka)';
$lang['error_requiressl'] = 'Izbran sistem za obdelavo plačil zahteva vzpostavitev varne (SSL) povezave, ki &scaron;e ni vzpostavljena';
$lang['error_retrieve_data'] = 'Pri&scaron;lo je do težave pri branju ustreznih informacij iz baze';
$lang['error_security_key'] = 'Ni bilo mogoče razbrati enkripcijskega ključa za to transakcijo';
$lang['error_paymentgateway_incompatible'] = 'Izbran modul za obdelavo plačil ni kompatibilen s tem modulom za procesiranje naročil. Prosimo, obvestite administratorja.';
$lang['error_permissiondenied'] = 'Dostop zavrnjen';
$lang['error_unknownstatus'] = 'Prejet neznan status iz sistema za obdelavo plačil';
$lang['error_usernotingroup'] = 'Trenutni uporabnik ni član zahtevane skupine';
$lang['fax'] = 'Fax';
$lang['filter'] = 'Filter';
$lang['first_name'] = 'Ime';
$lang['firstpage'] = '<<';
$lang['friendlyname'] = 'Upravitelj naročil';
$lang['from'] = 'Od';
$lang['gateway_module'] = 'Modul za obdelavo plačil';
$lang['gateway_complete_templates'] = 'Predloge za opravljeno plačilo';
$lang['gateway_failure_message'] = 'Va&scaron;a transakcija ni zaključena. Operacija je bila prekinjena, ali pa je pri&scaron;lo do napake. Prosimo, potrdite va&scaron;e informacije za plačilo in poizkusite ponovno. Va&scaron; voziček je bil izbrisan za va&scaron;o varnost. Zahvaljujemo se za razumevanje.';
$lang['general_settings'] = 'Splo&scaron;ne nastavitve';
$lang['help_param_nocaptcha'] = 'Če vklopite to možnost bo izklopljen captcha modul';
$lang['help_param_template'] = 'Določitev neprivzete predloge za uporabo pri privzeti akciji';
$lang['hold'] = 'Zadrži';
$lang['html'] = 'HTML';
$lang['html_email'] = 'Po&scaron;lji Email v HTML formatu';
$lang['id'] = 'ID';
$lang['incomplete'] = 'Nepopoln (delno poslano)';
$lang['info_admin_invoice_template'] = 'Izberite predlogo, ki bo uporabljena pri računu za tisk (popup - novo okno) pri upravljanju naročila';
$lang['info_adminemail_template'] = 'Predloga opredeljuje izgled in vsebino Email sporočila, ki je poslano avtoriziranemu administratorju, ko je prejeto novo naročilo';
$lang['info_allow_creditcard_entry'] = 'Nekateri sistemi za obdelavo plačil zahtevajo, da uporabnik vpi&scaron;e podatke o kreditni kartici na va&scaron;ih straneh preden po&scaron;lje informacijo v sistem za procesiranje plačil. Informacije o kreditnih karticah bodo začasno shranjene v kriptiranem zapisu do zaključka procesiranja oziroma preklica. Občasno brisanje začasnih informacij zagotavlja, da te informacije niso shranjene na va&scaron;em strežniku, razen če omogočite možnost shranjevanja informacij kreditnih kartic <em>(ni priporočljivo)</em>.';
$lang['info_billingpage'] = '<strong>Pozor:</strong> Ta nastavitev in njej podobne omogočajo administratorju uporabo različnih CMS strani za različne obrazce. Če izberete &quot;noben&quot;, bo uporabljena trenutna stran.';
$lang['info_default_templates'] = 'Obrazec nadzoruje vsebino predloge, ko kliknete &#039;Nova predloga&#039; v zavihku &#039;Predloge obrazca za potrditev naročila&#039;. Urejanje besedila tukaj nima neposrednega učinka na prikaz va&scaron;ih strani.';
$lang['info_encryption_key'] = 'Ključ je naključno generiran ob namestitvi modula. Če so v sistemu že naročila, bodite pozorni pri spreminjanju te nastavitve.';
$lang['info_forcessl'] = '<strong>Pozor: Priporočljivo</strong>.  Če omogočate kupcem vpis informacij o kreditni kartici, je zelo priporočljivo, da omogočite to možnost in zagotovite pravilno konfiguracijo SSL protokola na va&scaron;em strežniku. To bo omogočilo prenos informacij o kreditni kartici preko varne povezave.';
$lang['info_invoicepage'] = '<strong>Pozor:</strong> Ta stran se uporablja tudi ob uspe&scaron;nem ali neuspe&scaron;nem plačilu preko sistema za procesiranje plačil.';
$lang['info_order_notes'] = 'Vpi&scaron;ite posebna navodila pri tem naročilu';
$lang['info_skip_invoice_page'] = 'Če kupci lahko vpi&scaron;ejo informacije za plačilo,<br/>ali naj nadaljujejo na stran z računom<br/>ali neposredno na stran za zaključek transakcije?';
$lang['info_store_creditcard_data'] = '<strong>Pozor: <span style=&quot;color: red;&quot;>Ni priporočljivo</span></strong> Te informacije so shranjene v podatkovni bazi. Kljub enkripciji ni možno zagotoviti popolne varnosti. Priporočljivo je, da se te možnosti nikoli ne uporabi. Namesto tega, uporabite kompatibilen modul za procesiranje plačil.';
$lang['info_useremail_template'] = 'Ta predloga nadzoruje izgled in vsebino Email sporočila, ki je poslan kupcu ob zaključku nakupa';
$lang['info_use_integer'] = 'Uporabite samo &scaron;tevila';
$lang['interval_oneday'] = 'En dan';
$lang['interval_onemonth'] = 'En mesec';
$lang['interval_onequarter'] = 'Eno četrtletje';
$lang['interval_oneweek'] = 'En teden';
$lang['interval_oneyear'] = 'Eno leto';
$lang['interval_twoweeks'] = 'Dva tedna';
$lang['invoice'] = 'Račun';
$lang['invoiced'] = 'Izstavljen račun';
$lang['invoice_settings'] = 'Nastavitve računa';
$lang['invoice_templates'] = 'Predloge za račun';
$lang['items'] = 'Izdelki';
$lang['last_name'] = 'Priimek';
$lang['last_modified'] = 'Zadnja sprememba';
$lang['lastpage'] = '>>';
$lang['message'] = 'Sporočilo';
$lang['message_templates'] = 'Predloge sporočil';
$lang['moddescription'] = 'Preprost modul za obdelavo naročil';
$lang['modified'] = 'Spremenjeno';
$lang['name'] = 'Ime';
$lang['new_order_submitted'] = 'Oddano je bilo novo naročilo';
$lang['next'] = 'Naprej';
$lang['nextpage'] = '>';
$lang['no'] = 'Ne';
$lang['no_items_in_cart'] = 'Va&scaron; nakupovalni voziček je prazen. Prosimo, dodajte izdelke v voziček pred nadaljevanjem z nakupom.';
$lang['none'] = 'Noben';
$lang['notcancelledshipped'] = 'Vse razen Preklicani ali Poslani';
$lang['notshipped'] = 'Ni poslano';
$lang['num'] = '&Scaron;t.';
$lang['order'] = 'Naročilo';
$lang['orders'] = 'Naročila';
$lang['order_confirm_form_templates'] = 'Predloge za potrditev naročila';
$lang['order_details'] = 'Podrobnosti naročila';
$lang['order_notes'] = 'Zaznamki naročila';
$lang['order_number'] = '&Scaron;t. naročila';
$lang['order_processing'] = 'Spletni nakup';
$lang['order_statistics'] = 'Statistike naročil';
$lang['order_summary'] = 'Povzetek naročila';
$lang['paid'] = 'Plačano';
$lang['payment_form_templates'] = 'Predloge obrazca za plačilo';
$lang['payment_gateway_settings'] = 'Nastavitve sistema za obdelavo plačil';
$lang['payment_info'] = 'Informacije o plačilu';
$lang['payment_options'] = 'Možnosti plačila';
$lang['phone'] = 'Telefon';
$lang['popup_new_window'] = 'Odpri račun v novem oknu';
$lang['postinstall'] = 'Modul za obdelavo naročil je bil uspe&scaron;no name&scaron;čen';
$lang['postuninstall'] = 'Modul za obdelavo naročil in vsi njegovi podatki so bili odstranjeni';
$lang['post_order_msg'] = 'Sporočilo po naročilu';
$lang['postal'] = 'Po&scaron;tna &scaron;tevilka';
$lang['preferences'] = 'Nastavitve';
$lang['prevpage'] = '<';
$lang['price'] = 'Cena';
$lang['print_invoice'] = 'Natisni račun';
$lang['procede_manual_checkout'] = 'Nadaljuj z nakupom';
$lang['process_manual_payment'] = 'Nadaljuj s plačilom';
$lang['process_order'] = 'Procesiranje naročila';
$lang['product_id'] = 'ID produkta';
$lang['prompt_admin_invoice_template'] = 'Predloga za tisk računa';
$lang['prompt_allow_creditcard_entry'] = 'Dovoli kupcu vpis informacij o kreditni kartici';
$lang['prompt_billingpage'] = 'Stran, na kateri bo obrazec za naročilo. To je ponavadi stran, ki vsebuje oznako <code>{Orders}</code>.';
$lang['prompt_confirmpage'] = 'Stran z obrazcem za potrditev naročila';
$lang['prompt_date_search_type'] = 'Filtriraj zapise, ki so bili';
$lang['prompt_encryption_key'] = 'Ključ za kriptiranje';
$lang['prompt_forcessl'] = 'Preusmeri na HTTPS za vpis podatkov o plačilu';
$lang['prompt_invoice_message'] = 'Sporočilo za prikaz na začetku vseh računov';
$lang['prompt_invoicepage'] = 'Stran za prikaz računa';
$lang['prompt_of'] = 'od';
$lang['prompt_ordernum_prefix'] = 'Predpona &scaron;tevilke naročila';
$lang['prompt_page'] = 'Stran';
$lang['prompt_pagelimit'] = '&Scaron;t. naročil na stran';
$lang['prompt_paymentpage'] = 'Stran z obrazcem za plačilo';
$lang['prompt_permit_deletion'] = 'Dovoli brisanje naročil';
$lang['prompt_skip_invoice_page'] = 'Preskoči stran z računom';
$lang['prompt_store_creditcard_data'] = 'Trajno shrani informacije o kreditni kartici';
$lang['prompt_template'] = 'Predloga sporočila';
$lang['proposed'] = 'Predlagano';
$lang['quantity'] = 'Količina';
$lang['really_uninstall'] = 'Ste prepričani, da želite to nadaljevati? Vsi podatki, ki so povezani s tem modulom, bodo odstranjeni, če nadaljujete';
$lang['records_matching_query'] = '&Scaron;tevilo zapisov, ki ustreza va&scaron;i poizvedbi';
$lang['regex'] = 'Regularni izraz';
$lang['return'] = 'Nazaj';
$lang['require_group_membership'] = 'Zahtevaj, da so vsi uporabniki, ki nadaljujejo v nakup, člani te skupine v FrontEndUsers modulu';
$lang['security_settings'] = 'Nastavitve varnosti';
$lang['select_action'] = 'Izberite akcijo';
$lang['select_one'] = 'Izberite eno';
$lang['select_invoice_template'] = 'Izberite predlogo računa';
$lang['send'] = 'Po&scaron;lji';
$lang['send_message'] = 'Po&scaron;lji sporočilo kupcu';
$lang['sent'] = 'Poslano';
$lang['ship_to'] = 'Dostaviti na';
$lang['shipped'] = 'Poslano';
$lang['shipping'] = 'Dostava';
$lang['shipping_address'] = 'Naslov za dostavo';
$lang['shipping_info'] = 'Informacije za dostavo';
$lang['shipping_info_if_different'] = 'Informacije za dostavo <em>(izpolnite le, če se razlikujejo od informacij o kupcu)</em>';
$lang['shipping_message'] = 'Sporočilo, ki se nana&scaron;a na to destinacijo';
$lang['shipping_module'] = 'Modul za dostavo';
$lang['shipping_settings'] = 'Nastavitve za dostavo';
$lang['shipping_total'] = 'Skupaj dostava';
$lang['special_instructions'] = 'Posebna navodila';
$lang['state/province'] = 'Pokrajina';
$lang['status'] = 'Status';
$lang['subject'] = 'Zadeva';
$lang['submit'] = 'Po&scaron;lji';
$lang['submitted'] = 'Poslano';
$lang['submit_payment_info'] = 'Po&scaron;lji informacije za plačilo';
$lang['subtotal'] = 'Skupaj';
$lang['tax'] = 'DDV';
$lang['tax_module'] = 'Modul za davek';
$lang['tax_settings'] = 'Nastavitve davka';
$lang['template'] = 'Predloga';
$lang['template_name'] = 'Ime predloge';
$lang['thank_you_for_order'] = 'Zahvaljujemo se za va&scaron; nakup na {sitename}';
$lang['title_adminemail_template'] = 'Predloga Emaila administratorju';
$lang['title_first_page'] = 'Na prvo stran';
$lang['title_last_page'] = 'Na zadnjo stran';
$lang['title_manage_order'] = 'Urejanje naročila';
$lang['title_manual_process'] = 'Ročno procesiranje transakcij';
$lang['title_next_page'] = 'Naslednja stran';
$lang['title_prev_page'] = 'Prej&scaron;nja stran';
$lang['title_useremail_template'] = 'Predloga Emaila kupcu';
$lang['to'] = 'Za';
$lang['total'] = 'Za plačilo';
$lang['tracking_num'] = '&Scaron;tevilka za sledenje';
$lang['update_status'] = 'Posodobi status';
$lang['unit_price'] = 'Cena na enoto';
$lang['unit_weight'] = 'Teža enote';
$lang['unlimited'] = 'Neomejeno';
$lang['username'] = 'Uporabni&scaron;ko ime';
$lang['user_email_template'] = 'Predloga Emaila kupcu';
$lang['view'] = 'Prikaz';
$lang['view_message'] = 'Poglej sporočilo';
$lang['view_messages'] = 'Prikaži sporočila v zvezi s tem naročilom';
$lang['weight'] = 'Teža';
$lang['within'] = 'Med';
$lang['yes'] = 'Da';
$lang['utma'] = '156861353.946566493304929700.1236179099.1239346306.1242386301.8';
$lang['utmz'] = '156861353.1236861512.6.5.utmccn=(referral)|utmcsr=jupiter.sinusiks.net|utmcct=/admin/addtemplate.php|utmcmd=referral';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
